|CI| |Docs| |Coverage|

=========
pyaerocom
=========

**Website and Documentation:** https://pyaerocom.readthedocs.io/en/latest/

**Installation:** https://pyaerocom.readthedocs.io/en/latest/install.html  

**Tutorials:** https://pyaerocom.readthedocs.io/en/latest/pyaerocom-tutorials/index.html

**AeroCom:** https://aerocom.met.no

**AeroVal** evaluation portal: https://aeroval.met.no/

.. |CI| image:: https://github.com/metno/pyaerocom/workflows/CI/badge.svg
   :target: https://github.com/metno/pyaerocom/actions

.. |Docs| image:: https://readthedocs.org/projects/pyaerocom/badge/?version=latest
	 :target: https://pyaerocom.readthedocs.io/en/latest/?badge=latest
	 :alt: Documentation Status

.. |Coverage| image:: https://codecov.io/gh/metno/pyaerocom/branch/main-dev/graph/badge.svg?token=A0AdX8YciZ
    :target: https://codecov.io/gh/metno/pyaerocom

